package com.book.server.controller;

import com.book.dao.VO.SunVO;
import com.book.dao.polardb.entity.*;
import com.book.dao.utils.TimeUtil;
import com.book.server.common.entity.PageResult;
import com.book.server.common.entity.Result;
import com.book.server.config.SunTypeEnum;
import com.book.server.service.SunDataService;
import com.book.server.vo.SunNotifyRequest;
import com.book.server.vo.SunRequest;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.codec.digest.DigestUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletResponse;
import javax.websocket.server.PathParam;
import java.io.BufferedOutputStream;
import java.io.UnsupportedEncodingException;
import java.util.List;
import java.util.UUID;

/**
 * SUN
 * created in 2021/9/27
 * Project: book-store
 *
 * @author win7
 */
@RestController
@RequestMapping("/api/sun")
@Slf4j
public class SunDataController extends BaseController {
    @Autowired
    private SunDataService sunDataService;


    /**
     * getData
     *
     * @param type
     * @param request
     * @return
     */
    @PostMapping("/getData/{type}")
    public Result getData(@PathVariable("type") String type, @RequestBody SunRequest request) {
        SunTypeEnum sunTypeEnum = SunTypeEnum.valueOf(type);
        return sunDataService.requestData(request, sunTypeEnum);

    }

    /**
     * pullData
     *
     * @param request
     * @return
     */
    @PostMapping("/pullData")
    public String pushData(@RequestBody SunNotifyRequest request) {
        sunDataService.pullData(request);
        String s = "{\"code\":200,\"msg\":\"ok\"}";
        return s;

    }

    /**
     * 获取 渠道
     *
     * @param sunVO
     * @return
     */
    @PostMapping("/pageChannel")
    public Result<PageResult<SunChannel>> pageSunChannel(@RequestBody SunVO sunVO) {
        return Result.success(sunDataService.pageSunChannel(sunVO));
    }

    /**
     * 获取 订单明细表
     *
     * @param sunVO
     * @return
     */
    @PostMapping("/pageOrder")
    public Result<PageResult<SunOrder>> pageOrder(@RequestBody SunVO sunVO) {
        return Result.success(sunDataService.pageSunOrder(sunVO));
    }

    /**
     * 获取 订单统计表
     *
     * @param sunVO
     * @return
     */
    @PostMapping("/pageOrderCollect")
    public Result<PageResult<SunOrderCollect>> pageOrderCollect(@RequestBody SunVO sunVO) {
        return Result.success(sunDataService.pageOrderCollect(sunVO));
    }

    /**
     * 获取 用户统计表
     *
     * @param sunVO
     * @return
     */
    @PostMapping("/pageUserCollect")
    public Result<PageResult<SunUserCollect>> pageUserCollect(@RequestBody SunVO sunVO) {
        return Result.success(sunDataService.pageUserCollect(sunVO));
    }

    /**
     * 统计某天的订单
     *
     * @param date
     * @return
     */
    @GetMapping("/orderStaticByDate-F891088E-7A75-4F4B-AEB4-A9D1697F5AD3")
    public Result<PageResult<SunUserCollect>> orderStaticByDate(String date) {
        sunDataService.orderStaticDate(date);
        return Result.success();
    }

    /**
     * 获取今天订单统计
     *
     * @return
     */
    @GetMapping("/getTodayOrderStatic")
    public Result getTodayOrderStatic() {
        return Result.success(sunDataService.getTodayOrderStatic());
    }

    /**
     * 获取今天订单统计按渠道
     *
     * @return
     */
    @GetMapping("/getTodayOrderStaticByChannel")
    public Result getTodayOrderStaticByChannel() {
        return Result.success(sunDataService.getTodayOrderStaticByChannel());
    }

    @GetMapping("/exportTodayOrderStaticByChannel")
    public void exportTodayOrderStaticByChannel(HttpServletResponse response) throws UnsupportedEncodingException {
        List<SunStaticOrderDayChannel> list = sunDataService.getTodayOrderStaticByChannel();

        /**
         * 导出
         */
        response.setContentType("text/plain");
        String fileName = TimeUtil.getTodayStr() + UUID.randomUUID() + ".csv";
        response.setHeader("Content-Disposition", "attachment; filename=" + java.net.URLEncoder.encode(fileName, "UTF-8"));

        BufferedOutputStream buff = null;
        StringBuffer write = new StringBuffer();
        String enter = "\r\n";
        ServletOutputStream outSTr = null;
        try {
            outSTr = response.getOutputStream();
            buff = new BufferedOutputStream(outSTr);
            // 把内容写入文件
            if (list.size() > 0) {
                // 添加表头
                write.append("日期,渠道 Id,渠道名称,活跃用户数,充值用户数,充值金额,充值笔数,充值人均");
                write.append(enter);

                for (int i = 0; i < list.size(); i++) {
                    SunStaticOrderDayChannel text = list.get(i);
                    write.append(text.getStaticDate() + "," + text.getChannelId() + ","+ text.getChannelName() + ","+ text.getActiveCount() + "," + text.getRechargeUserCount() + "," + text.getRechargeSum() + "," + text.getRechargeCount() + "," + text.getRechargeAvg());
                    write.append(enter);
                }
            }
            buff.write(write.toString().getBytes("UTF-8"));
            buff.flush();
            buff.close();
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            try {
                buff.close();
                outSTr.close();
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    @GetMapping("/exportOrderStaticAll")
    public void exportTodayOrderStatic(HttpServletResponse response) throws UnsupportedEncodingException {
        List<SunStaticOrderDay> list = sunDataService.getOrderStaticsAll();
        /**
         * 导出
         */
        response.setContentType("text/plain");
        String fileName = TimeUtil.getTodayStr() + UUID.randomUUID() + ".csv";
        response.setHeader("Content-Disposition", "attachment; filename=" + java.net.URLEncoder.encode(fileName, "UTF-8"));

        BufferedOutputStream buff = null;
        StringBuffer write = new StringBuffer();
        String enter = "\r\n";
        ServletOutputStream outSTr = null;
        try {
            outSTr = response.getOutputStream();
            buff = new BufferedOutputStream(outSTr);
            // 把内容写入文件
            if (list.size() > 0) {
                // 添加表头
                write.append("日期,活跃用户数,充值用户数,充值金额,充值笔数,充值人均");
                write.append(enter);

                for (int i = 0; i < list.size(); i++) {
                    SunStaticOrderDay text = list.get(i);
                    write.append(text.getStaticDate() + "," + text.getActiveCount() + "," + text.getRechargeUserCount() + "," + text.getRechargeSum() + "," + text.getRechargeCount() + "," + text.getRechargeAvg());
                    write.append(enter);
                }
            }
            buff.write(write.toString().getBytes("UTF-8"));
            buff.flush();
            buff.close();
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            try {
                buff.close();
                outSTr.close();
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    /**
     * 获取昨天订单统计
     *
     * @return
     */
    @GetMapping("/getYesterdayOrderStatic")
    public Result getYesterdayOrderStatic() {
        return Result.success(sunDataService.getYesterdayOrderStatic());
    }

    /**
     * 获取历史订单统计
     *
     * @return
     */
    @GetMapping("/getHistoryOrderStatic")
    public Result getHistoryOrderStatic() {
        return Result.success(sunDataService.getHistoryOrderStatic());
    }

    /**
     * 订单统计-按天排序
     *
     * @return
     */
    @GetMapping("/getOrderStatics")
    public Result getOrderStatics(int page, int size) {
        return Result.success(sunDataService.getOrderStatics(page, size));
    }

    /**
     * 订单统计-按天查询
     *
     * @return
     */
    @GetMapping("/getOrderStaticByDateAndChannel")
    public Result getOrderStaticByDateAndChannel(String date) {
        return Result.success(sunDataService.getOrderStaticByDateAndChannel(date));
    }


    public static void main(String[] args) {
        System.out.println(UUID.randomUUID().toString());
    }

}
