package com.book.server.task;

import com.book.dao.utils.TimeUtil;
import com.book.server.config.SunTypeEnum;
import com.book.server.service.SunDataService;
import com.book.server.vo.SunRequest;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import java.util.Calendar;
import java.util.Date;

/**
 * created in 2021/9/28
 * Project: book-store
 *
 * @author win7
 */
@Component
@EnableScheduling
@Slf4j
public class SunDataTask {
    public static final Integer FIX_DELAY_HOUR = 1;

    @Autowired
    private SunDataService sunDataService;

    @Scheduled(cron = "0 0 0/1 * * ?")
    private void getData() {
        log.info("定时拉取sun数据");
        String timeFrom = TimeUtil.getDateStrAfter(-FIX_DELAY_HOUR, Calendar.HOUR_OF_DAY, TimeUtil.YYYY_M_DD_HH_MM_SS);
        String timeNow = TimeUtil.getCurrentDate(TimeUtil.YYYY_M_DD_HH_MM_SS);
        String dateNow = TimeUtil.getCurrentDate(TimeUtil.YYYYMMDD1);

        String channelId = "";


        for (SunTypeEnum sunTypeEnum : SunTypeEnum.values()) {
            SunRequest request = new SunRequest();

            switch (sunTypeEnum) {
                case user_collect:

                case user:
                    request.setStart_time(timeFrom);
                    request.setEnd_time(timeNow);
                    sunDataService.requestData(request, sunTypeEnum);

                    break;
                case user_active:
                    request.setSearch_date(dateNow);
                    sunDataService.requestData(request, sunTypeEnum);

                    break;

                case order:
                    request.setStart_time(timeFrom);
                    request.setEnd_time(timeNow);
                    request.setIs_finish("1");
                    sunDataService.requestData(request, sunTypeEnum);
                    break;

                default:
                    break;

            }


        }
    }



    @Scheduled(cron = "0 30 0 * * ?")
    private void getYesterdayData() {
        log.info("定时拉取sun昨日数据");

        Date yesterday = TimeUtil.getYesterday(-1);
        String date = TimeUtil.dateToStr(yesterday,TimeUtil.YYYYMMDD1);


        for (SunTypeEnum sunTypeEnum : SunTypeEnum.values()) {
            SunRequest request = new SunRequest();

            switch (sunTypeEnum) {

                case user_active:
                    request.setSearch_date(date);
                    sunDataService.requestData(request, sunTypeEnum);

                    break;



                default:
                    break;

            }


        }
    }

    /**
     * 订单昨日统计
     * 凌晨 1 点 15 分
     */
    @Scheduled(cron = "1 15 0 * * ?")
    public void OrderStaticYesterday() {
        String yesterdayStr = TimeUtil.getYesterdayStr();
        sunDataService.orderStaticDate(yesterdayStr);
    }

    public static void main(String[] args) {
        System.out.println(TimeUtil.getTodayStr());
        System.out.println(TimeUtil.getYesterdayStr());
    }
}
